import 'package:dio/dio.dart';

import 'api_interceptor.dart';

const _requestTimeoutInMilliseconds = 40000;

abstract class DioModule {
  // @Named("Host")
  String get host => 'api.myfaceid.uz';

  // @Named("TestHost")
  String get testHost =>'dev-mobile.soliq.uz';

  // @Named("Environment")
  bool get isTest => const bool.hasEnvironment("isTest");

  // @singleton
  Future<Dio> getAuthorizedDioClient({
    required bool isTest,
   required String host,
     required String testHost,
  }) async {
    String _baseUrl = 'https://$host/';
    final authorizedDioClient = _createDioClient(_baseUrl);
    authorizedDioClient.interceptors.addAll([
      AuthorizedRequestInterceptor(
        authorizedDioClient,
      ),
    ]);
    return authorizedDioClient;
  }

  // @Named("UnauthorizedClient")
  // @singleton
  Future<Dio> getUnauthorizedDioClient({
    required bool isTest,
   required String host,
    required String testHost,
  }) async {
    String _baseUrl = 'https://$host/';
    final unauthorizedDioClient = _createDioClient(_baseUrl);
    unauthorizedDioClient.interceptors.addAll([
      CommonRequestInterceptor(unauthorizedDioClient,
    ),
    ]);
    return unauthorizedDioClient;
  }

  Dio _createDioClient(String baseUrl) {
    final options = BaseOptions(
      baseUrl: baseUrl,
      receiveDataWhenStatusError: true,
      // connectTimeout: _requestTimeoutInMilliseconds,
      // receiveTimeout: _requestTimeoutInMilliseconds,
    );
    return Dio(options);
  }
}
